@@ -171,7 +171,11 @@ class EsHelper:
         }
         try:
             if options.correction_param.get("enable"):
-                self.correction_param(params, route_key)
+                mappings = self.pool.es_selector_way(url_func_str=self.pool.format_es_mapping_url,
+                                                     param_dict={"route_key": route_key},
+                                                     request_way="get").get(route_key, {}).get("mappings", {}).get(
+                    "properties", {})
+                self.correction_param(params, mappings)
         except:
             logging.error(traceback.format_exc())
         if track_total_hits:
@@ -191,48 +195,69 @@ class EsHelper:
             logging.info(res)
         return res["hits"]
 
-    def correction_param(self, param, route_key):
+    def correction_param(self, param, mappings):
         for k in param:
             if k in ["terms", "term", "range", "wildcard"]:
-                param[k] = self.correction_field(route_key, param[k], keyword_flag=True)
+                param[k] = self.correction_field(param[k], mappings, keyword_flag=True)
             elif k in ["match", "match_phrase"]:
-                param[k] = self.correction_field(route_key, param[k])
+                param[k] = self.correction_field(param[k], mappings)
             else:
                 if isinstance(param[k], dict):
-                    self.correction_param(param[k], route_key)
+                    self.correction_param(param[k], mappings)
                 elif isinstance(param[k], list):
                     for i in param[k]:
-                        self.correction_param(i, route_key)
+                        self.correction_param(i, mappings)
 
-    def correction_field(self, route_key, value, keyword_flag=False):
-        column = list(value.keys())[0]
-        data_value = value[column]
+    def correction_field(self, value, mappings, keyword_flag=False):
+        if value.get("field"):
+            column = value["field"]
+            column = self.check_replace_keyword(column, mappings, keyword_flag)
+            value["field"] = column
+            return value
+        else:
+            column = list(value.keys())[0]
+            data_value = value[column]
+            column = self.check_replace_keyword(column, mappings, keyword_flag)
+            return {
+                column: data_value
+            }
+
+    def check_replace_keyword(self, column, mappings, keyword_flag):
         column = column.replace(".keyword", "")
-        es_mapping_value = self.get_es_filed_mapping(route_key, column)
+        es_mapping_value = self.get_es_filed_mapping(column, mappings)
         if es_mapping_value:
             if es_mapping_value.get("text") and es_mapping_value.get("keyword"):
                 if keyword_flag:
                     column = f'{column}.keyword'
-        return {
-            column: data_value
-        }
+        return column
 
-    def get_es_filed_mapping(self, route_key, field):
-        res = self.pool.es_selector_way(url_func_str=self.pool.format_es_field_mapping_url,
-                                        param_dict={"field": field, "route_key": route_key},
-                                        request_way="get").get(route_key, {}).get("mappings", {}).get(
-            field, {}).get("mapping", {}).get(field.split(".")[-1], {})
-        if res.get("fields"):
-            result = {
-                res["type"]: 1,
-                list(res["fields"].values())[0]["type"]: 1
-            }
+    def get_es_filed_mapping(self, field, mappings):
+        field_list = field.split(".")
+        res = self.get_field_children_mapping(field_list, mappings)
+        if res:
+            if res.get("fields"):
+                result = {
+                    res["type"]: 1,
+                    list(res["fields"].values())[0]["type"]: 1
+                }
+            else:
+                result = {
+                    res["type"]: 1
+                }
         else:
-            result = {
-                res["type"]: 1
-            }
+            result = {}
         return result
 
+    def get_field_children_mapping(self, field_list, mapping):
+        if field_list:
+            mapping = mapping.get(field_list[0])
+            field_list = field_list[1:]
+            if field_list:
+                mapping = mapping.get("properties")
+                return self.get_field_children_mapping(field_list, mapping)
+            else:
+                return mapping
+
     def get_mapping_text_and_keyword_column(self, mapping, reuslt, column=""):
         for key in mapping:
             # 获取value的key都有什么是否拥有type和fields
@@ -279,7 +304,7 @@ class EsHelper:
         logging.info("扫描开始，条件是{},查询字段是{}".format(json.dumps(bool_must_list), json.dumps(param_list)))
         skip = 0
         limit = offset + limit
-        request_param = {
+        params = {
             "query": {
                 "bool": {
                     "must": bool_must_list
@@ -287,14 +312,23 @@ class EsHelper:
             }
             , "size": size
         }
+        try:
+            if options.correction_param.get("enable"):
+                mappings = self.pool.es_selector_way(url_func_str=self.pool.format_es_mapping_url,
+                                                     param_dict={"route_key": route_key},
+                                                     request_way="get").get(route_key, {}).get("mappings", {}).get(
+                    "properties", {})
+                self.correction_param(params, mappings)
+        except:
+            logging.error(traceback.format_exc())
         if param_list:
-            request_param["_source"] = {"include": param_list}
+            params["_source"] = {"include": param_list}
         if sort_list:
-            request_param["sort"] = sort_list
+            params["sort"] = sort_list
         res = self.pool.es_selector_way(url_func_str=self.pool.format_scroll_url, param_dict={
             "route_key": route_key,
             "scroll": scroll
-        }, find_condition=request_param)
+        }, find_condition=params)
         data_size = len(res["hits"]["hits"])
         logging.info(
             "扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
@@ -338,6 +372,16 @@ class EsHelper:
             "size": 0,
             "aggs": aggs
         }
+        try:
+            if options.correction_param.get("enable"):
+                mappings = self.pool.es_selector_way(url_func_str=self.pool.format_es_mapping_url,
+                                                     param_dict={"route_key": route_key},
+                                                     request_way="get").get(route_key, {}).get("mappings", {}).get(
+                    "properties", {})
+                self.correction_param(params, mappings)
+        except:
+            logging.error(traceback.format_exc())
+
         res = self.pool.es_selector_way(url_func_str=self.pool.format_es_post_url, param_dict={
             "route_key": route_key,
         }, find_condition=params)
